@@ -19,8 +19,8 @@ use swc_common::{
 };
 use swc_ecma_ast::*;
 use swc_ecma_utils::{
-    ident::IdentLike, undefined, ExprExt, ExprFactory, Id, IsEmpty, ModuleItemLike, StmtLike, Type,
-    Value,
+    ident::IdentLike, prepend_stmts, undefined, ExprExt, ExprFactory, Id, IsEmpty, ModuleItemLike,
+    StmtLike, Type, Value,
 };
 use swc_ecma_visit::{noop_visit_mut_type, VisitMut, VisitMutWith, VisitWith};
 use tracing::{span, Level};
@@ -1482,12 +1482,39 @@ where
     noop_visit_mut_type!();
 
     fn visit_mut_arrow_expr(&mut self, n: &mut ArrowExpr) {
+        let prepend = self.prepend_stmts.take();
+
         let ctx = Ctx {
             can_inline_arguments: true,
             ..self.ctx
         };
 
         n.visit_mut_children_with(&mut *self.with_ctx(ctx));
+
+        if !self.prepend_stmts.is_empty() {
+            let mut stmts = self.prepend_stmts.take();
+            match &mut n.body {
+                BlockStmtOrExpr::BlockStmt(v) => {
+                    prepend_stmts(&mut v.stmts, stmts.into_iter());
+                }
+                BlockStmtOrExpr::Expr(v) => {
+                    self.changed = true;
+                    if cfg!(feature = "debug") {
+                        tracing::debug!("Convertng a body of an arrow expression to BlockStmt");
+                    }
+                    stmts.push(Stmt::Return(ReturnStmt {
+                        span: DUMMY_SP,
+                        arg: Some(v.take()),
+                    }));
+                    n.body = BlockStmtOrExpr::BlockStmt(BlockStmt {
+                        span: DUMMY_SP,
+                        stmts,
+                    });
+                }
+            }
+        }
+
+        self.prepend_stmts = prepend;
     }
 
     fn visit_mut_assign_expr(&mut self, e: &mut AssignExpr) {
@@ -1564,6 +1591,18 @@ where
         n.visit_mut_children_with(&mut *self.with_ctx(ctx));
     }
 
+    fn visit_mut_block_stmt_or_expr(&mut self, n: &mut BlockStmtOrExpr) {
+        n.visit_mut_children_with(self);
+
+        match n {
+            BlockStmtOrExpr::BlockStmt(n) => {
+                self.merge_if_returns(&mut n.stmts, false, true);
+                self.drop_else_token(&mut n.stmts);
+            }
+            BlockStmtOrExpr::Expr(_) => {}
+        }
+    }
+
     fn visit_mut_call_expr(&mut self, e: &mut CallExpr) {
         let inline_prevented = self.ctx.inline_prevented || self.has_noinline(e.span);
 
